/* Calcite, kernel/src/entry.c
 * Copyright 2025 Benji Dial
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <limine.h>

LIMINE_BASE_REVISION(3)

static volatile struct limine_framebuffer_request fb_request = {
  .id = LIMINE_FRAMEBUFFER_REQUEST,
  .revision = 0,
  .response = 0
};

[[noreturn]] static void die() {
  while (1)
    __asm__ ("hlt");
}

[[noreturn]] void kernel_entry() {

  if (fb_request.response == 0 || fb_request.response->framebuffer_count == 0)
    die();

  struct limine_framebuffer *fb = fb_request.response->framebuffers[0];

  for (uint64_t y = 0; y < fb->height; ++y)
    for (uint64_t x = 0; x < fb->width; ++x) {
      uint8_t *pixel = (uint8_t *)fb->address + y * fb->pitch + x * 4;
      pixel[0] = y * 256 / fb->height;
      pixel[1] = x * 256 / fb->width;
      pixel[2] = 0;
    }

  die();

}
